@@ -1,4 +1,4 @@
-/* $Id: global.c 4248 2008-03-31 06:25:14Z astyanax $ 
+/* $Id: global.c 4264 2008-06-03 08:09:05Z astyanax $ 
 */
 /**************************************************************************
  *   global.c                                                             *
@@ -1032,7 +1032,7 @@ void shortcut_init(bool unjustify)
     add_to_sclist(MMAIN, "F10", do_uncut_text, 0, TRUE);
     add_to_sclist(MMAIN, "^C", do_cursorpos_void, 0, TRUE);
     add_to_sclist(MMAIN, "F11", do_cursorpos_void, 0, TRUE);
-#ifndef NANO_TINY
+#ifndef DISABLE_SPELLER
     add_to_sclist(MMAIN, "^T", do_spell, 0, TRUE);
     add_to_sclist(MMAIN, "F12", do_spell, 0, TRUE);
 #endif
@@ -1056,23 +1056,29 @@ void shortcut_init(bool unjustify)
     add_to_sclist(MMAIN, "M-}", do_indent_void, 0, TRUE);
     add_to_sclist(MMAIN, "M-{", do_unindent, 0, TRUE);
     add_to_sclist(MALL, "^F", do_right, 0, TRUE);
-    add_to_sclist(MALL, "kright", do_right, 0, TRUE);
     add_to_sclist(MALL, "^B", do_left, 0, TRUE);
-    add_to_sclist(MALL, "kleft", do_left, 0, TRUE);
     add_to_sclist(MMAIN, "^Space", do_next_word_void, 0, TRUE);
     add_to_sclist(MMAIN, "M-Space", do_prev_word_void, 0, TRUE);
 #endif
+    add_to_sclist(MALL, "kright", do_right, 0, TRUE);
+    add_to_sclist(MALL, "kleft", do_left, 0, TRUE);
     add_to_sclist(MMAIN, "^Q", xon_complaint, 0, TRUE);
     add_to_sclist(MMAIN, "^S", xoff_complaint, 0, TRUE);
-    add_to_sclist(MALL, "^P", do_up_void, 0, TRUE);
-    add_to_sclist(MALL, "kup", do_up_void, 0, TRUE);
-    add_to_sclist(MALL, "^N", do_down_void, 0, TRUE);
-    add_to_sclist(MALL, "kdown", do_down_void, 0, TRUE);
+    add_to_sclist(MMAIN, "^P", do_up_void, 0, TRUE);
+    add_to_sclist(MMAIN, "kup", do_up_void, 0, TRUE);
+    add_to_sclist(MMAIN, "^N", do_down_void, 0, TRUE);
+    add_to_sclist(MMAIN, "kdown", do_down_void, 0, TRUE);
     add_to_sclist(MALL, "^A", do_home, 0, TRUE);
     add_to_sclist(MALL, "khome", do_home, 0, TRUE);
     add_to_sclist(MALL, "^E", do_end, 0, TRUE);
     add_to_sclist(MALL, "kend", do_end, 0, TRUE);
 #ifndef DISABLE_JUSTIFY
+#ifndef NANO_TINY
+    add_to_sclist(MWHEREIS|MREPLACE|MREPLACE2|MWHEREISFILE, "^P", (void *) prev_history_msg, 0, FALSE);
+    add_to_sclist(MWHEREIS|MREPLACE|MREPLACE2|MWHEREISFILE, "kup", (void *) prev_history_msg, 0, FALSE);
+    add_to_sclist(MWHEREIS|MREPLACE|MREPLACE2|MWHEREISFILE, "^N", (void *) next_history_msg, 0, FALSE);
+    add_to_sclist(MWHEREIS|MREPLACE|MREPLACE2|MWHEREISFILE, "kdown", (void *) next_history_msg, 0, FALSE);
+#endif
     add_to_sclist(MWHEREIS|MREPLACE|MREPLACE2,
 	"^W", do_para_begin_void, 0, TRUE);
     add_to_sclist(MWHEREIS|MREPLACE|MREPLACE2,
