@@ -1,4 +1,4 @@
-/* $Id: nano.c 4247 2008-03-20 05:56:46Z astyanax $ */
+/* $Id: nano.c 4256 2008-05-31 22:23:16Z astyanax $ */
 /**************************************************************************
  *   nano.c                                                               *
  *                                                                        *
@@ -611,7 +611,7 @@ void die(const char *msg, ...)
     va_end(ap);
 
     /* Save the current file buffer if it's been modified. */
-    if (openfile->modified) {
+    if (openfile && openfile->modified) {
 	/* If we've partitioned the filestruct, unpartition it now. */
 	if (filepart != NULL)
 	    unpartition_filestruct(&filepart);
