@@ -1,4 +1,4 @@
-/* $Id: proto.h 4226 2008-03-14 04:08:51Z astyanax $ */
+/* $Id: proto.h 4264 2008-06-03 08:09:05Z astyanax $ */
 /**************************************************************************
  *   proto.h                                                              *
  *                                                                        *
@@ -632,7 +632,7 @@ bool do_wrap(filestruct *line);
 #if !defined(DISABLE_HELP) || !defined(DISABLE_WRAPJUSTIFY)
 ssize_t break_line(const char *line, ssize_t goal
 #ifndef DISABLE_HELP
-	, bool newline
+	, bool newln
 #endif
 	);
 #endif
@@ -788,6 +788,8 @@ const char *cancel_msg;
 #ifndef NANO_TINY
 const char *case_sens_msg;
 const char *backwards_msg;
+const char *prev_history_msg;
+const char *next_history_msg;
 #endif
 const char *replace_msg;
 const char *no_replace_msg;
